Parrhesia.Release (parrhesia v0.12.0)

Helpers for running Ecto tasks from a production release.

Intended for use from a release eval command where Mix is not available:

bin/parrhesia eval "Parrhesia.Release.migrate()"
bin/parrhesia eval "Parrhesia.Release.rollback(Parrhesia.Repo, 20260101000000)"

Summary

Functions

Runs all pending Ecto migrations for every configured repo.

Rolls back the given repo to the specified migration version.

Functions

migrate()

Runs all pending Ecto migrations for every configured repo.

rollback(repo, version)

Rolls back the given repo to the specified migration version.